# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedResponseItemRankWithUnitResponse(Model):
    """AggregatedResponseItemRankWithUnitResponse.

    :param period:
    :type period: ~energycap.sdk.models.PeriodRange
    :param total:
    :type total: ~energycap.sdk.models.ItemRankWithUnitResponse
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.ItemRankWithUnitResponse]
    """

    _attribute_map = {
        'period': {'key': 'period', 'type': 'PeriodRange'},
        'total': {'key': 'total', 'type': 'ItemRankWithUnitResponse'},
        'data_details': {'key': 'dataDetails', 'type': '[ItemRankWithUnitResponse]'},
    }

    def __init__(self, **kwargs):
        super(AggregatedResponseItemRankWithUnitResponse, self).__init__(**kwargs)
        self.period = kwargs.get('period', None)
        self.total = kwargs.get('total', None)
        self.data_details = kwargs.get('data_details', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGScope(Model):
    """GHGScope.

    :param scope_id: The Scope Identifier
    :type scope_id: int
    :param scope_info: The Scope Info
    :type scope_info: str
    """

    _attribute_map = {
        'scope_id': {'key': 'scopeId', 'type': 'int'},
        'scope_info': {'key': 'scopeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGScope, self).__init__(**kwargs)
        self.scope_id = kwargs.get('scope_id', None)
        self.scope_info = kwargs.get('scope_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillUseRequest(Model):
    """Defines how use is calculated for a calculated bill distribution.

    :param readings_channel_id: Use monthly channel data readings to calculate
     bill use <span class='property-internal'>Required (defined)</span>
    :type readings_channel_id: int
    :param fixed_amount:
    :type fixed_amount: ~energycap.sdk.models.FixedUseRequest
    :param copy_use_from_meter:
    :type copy_use_from_meter: ~energycap.sdk.models.CopyMeterRequest
    :param use_calculation:
    :type use_calculation: ~energycap.sdk.models.CalculationRequest
    :param calendarized_use_calculation:
    :type calendarized_use_calculation:
     ~energycap.sdk.models.CalendarizedCalculationRequest
    :param use_wattics_data_point: Use Wattics data readings to calculate bill
     use <span class='property-internal'>One of True </span> <span
     class='property-internal'>Required (defined)</span>
    :type use_wattics_data_point: bool
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'FixedUseRequest'},
        'copy_use_from_meter': {'key': 'copyUseFromMeter', 'type': 'CopyMeterRequest'},
        'use_calculation': {'key': 'useCalculation', 'type': 'CalculationRequest'},
        'calendarized_use_calculation': {'key': 'calendarizedUseCalculation', 'type': 'CalendarizedCalculationRequest'},
        'use_wattics_data_point': {'key': 'useWatticsDataPoint', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(CalculatedBillUseRequest, self).__init__(**kwargs)
        self.readings_channel_id = kwargs.get('readings_channel_id', None)
        self.fixed_amount = kwargs.get('fixed_amount', None)
        self.copy_use_from_meter = kwargs.get('copy_use_from_meter', None)
        self.use_calculation = kwargs.get('use_calculation', None)
        self.calendarized_use_calculation = kwargs.get('calendarized_use_calculation', None)
        self.use_wattics_data_point = kwargs.get('use_wattics_data_point', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGCarbonFootprintResponse(Model):
    """GHGCarbonFootprintResponse.

    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRange
    :param target_data:
    :type target_data: ~energycap.sdk.models.GHGTargetEmissions
    :param yearly_data: GHG Emissions data, split by year, then by group and
     gas type.
    :type yearly_data: list[~energycap.sdk.models.GHGYearlyEmissions]
    """

    _attribute_map = {
        'period_range': {'key': 'periodRange', 'type': 'PeriodRange'},
        'target_data': {'key': 'targetData', 'type': 'GHGTargetEmissions'},
        'yearly_data': {'key': 'yearlyData', 'type': '[GHGYearlyEmissions]'},
    }

    def __init__(self, *, period_range=None, target_data=None, yearly_data=None, **kwargs) -> None:
        super(GHGCarbonFootprintResponse, self).__init__(**kwargs)
        self.period_range = period_range
        self.target_data = target_data
        self.yearly_data = yearly_data



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceLinkResponse(Model):
    """EnergyStarPlaceLinkResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param submit_mode: The submit mode. Could be "Meter" or "Commodity"
    :type submit_mode: str
    :param pm_property_id: una co
     The Portfolio Manager property identifier
    :type pm_property_id: long
    :param meters: List of meters for this place
    :type meters: list[~energycap.sdk.models.EnergyStarMeterLinkChild]
    :param commodities: List of commodities for this place
    :type commodities:
     list[~energycap.sdk.models.EnergyStarCommodityLinkChild]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'submit_mode': {'key': 'submitMode', 'type': 'str'},
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'meters': {'key': 'meters', 'type': '[EnergyStarMeterLinkChild]'},
        'commodities': {'key': 'commodities', 'type': '[EnergyStarCommodityLinkChild]'},
    }

    def __init__(self, *, place=None, submit_mode: str=None, pm_property_id: int=None, meters=None, commodities=None, **kwargs) -> None:
        super(EnergyStarPlaceLinkResponse, self).__init__(**kwargs)
        self.place = place
        self.submit_mode = submit_mode
        self.pm_property_id = pm_property_id
        self.meters = meters
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetSavingsYearlyResponse(Model):
    """WidgetSavingsYearlyResponse.

    :param billing_period_range:
    :type billing_period_range: ~energycap.sdk.models.PeriodRange
    :param fiscal_period_range:
    :type fiscal_period_range: ~energycap.sdk.models.PeriodRange
    :param all_time_batcc_use: Program to Date BATCC (Baseline Adjusted to
     Current Conditions) Use
    :type all_time_batcc_use: float
    :param all_time_use: Program to Date Use
    :type all_time_use: float
    :param all_time_savings_use: Program to Date Savings Use = allTimeBATCCUse
     - allTimeUse
    :type all_time_savings_use: float
    :param all_time_batcc_total_cost: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Total Cost
    :type all_time_batcc_total_cost: float
    :param all_time_total_cost: Program to Date Savings Total Cost
    :type all_time_total_cost: float
    :param all_time_savings_total_cost: Program to Date Savings Total Cost =
     allTimeBATCCTotalCost - allTimeTotalCost
    :type all_time_savings_total_cost: float
    :param results: An array of savings yearly data
    :type results:
     list[~energycap.sdk.models.WidgetSavingsYearlyResponseResults]
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of savings yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.WidgetSavingsYearlyResponseCommodityData]
    """

    _attribute_map = {
        'billing_period_range': {'key': 'billingPeriodRange', 'type': 'PeriodRange'},
        'fiscal_period_range': {'key': 'fiscalPeriodRange', 'type': 'PeriodRange'},
        'all_time_batcc_use': {'key': 'allTimeBATCCUse', 'type': 'float'},
        'all_time_use': {'key': 'allTimeUse', 'type': 'float'},
        'all_time_savings_use': {'key': 'allTimeSavingsUse', 'type': 'float'},
        'all_time_batcc_total_cost': {'key': 'allTimeBATCCTotalCost', 'type': 'float'},
        'all_time_total_cost': {'key': 'allTimeTotalCost', 'type': 'float'},
        'all_time_savings_total_cost': {'key': 'allTimeSavingsTotalCost', 'type': 'float'},
        'results': {'key': 'results', 'type': '[WidgetSavingsYearlyResponseResults]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[WidgetSavingsYearlyResponseCommodityData]'},
    }

    def __init__(self, *, billing_period_range=None, fiscal_period_range=None, all_time_batcc_use: float=None, all_time_use: float=None, all_time_savings_use: float=None, all_time_batcc_total_cost: float=None, all_time_total_cost: float=None, all_time_savings_total_cost: float=None, results=None, updated=None, use_unit=None, cost_unit=None, commodities=None, **kwargs) -> None:
        super(WidgetSavingsYearlyResponse, self).__init__(**kwargs)
        self.billing_period_range = billing_period_range
        self.fiscal_period_range = fiscal_period_range
        self.all_time_batcc_use = all_time_batcc_use
        self.all_time_use = all_time_use
        self.all_time_savings_use = all_time_savings_use
        self.all_time_batcc_total_cost = all_time_batcc_total_cost
        self.all_time_total_cost = all_time_total_cost
        self.all_time_savings_total_cost = all_time_savings_total_cost
        self.results = results
        self.updated = updated
        self.use_unit = use_unit
        self.cost_unit = cost_unit
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterLinkRequest(Model):
    """MeterLinkRequest.

    :param meter_id: The identifier for a Meter.
     Set to null to remove the link. <span class='property-internal'>Topmost
     (Meter)</span> <span class='property-internal'>Required (defined)</span>
    :type meter_id: int
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
    }

    def __init__(self, *, meter_id: int=None, **kwargs) -> None:
        super(MeterLinkRequest, self).__init__(**kwargs)
        self.meter_id = meter_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCategoryResponse(Model):
    """MeterCategoryResponse.

    :param meter_group_category_id: The meter category identifier
    :type meter_group_category_id: int
    :param meter_group_category_code: The meter category code
    :type meter_group_category_code: str
    :param meter_group_category_info: The meter category name
    :type meter_group_category_info: str
    :param auto_group: Is this category an automatically maintained one?
    :type auto_group: bool
    :param number_of_groups: Number of groups within this category
    :type number_of_groups: int
    :param number_of_groups_with_visible_members: Number of groups within this
     category with members the logged in can see
    :type number_of_groups_with_visible_members: int
    """

    _attribute_map = {
        'meter_group_category_id': {'key': 'meterGroupCategoryId', 'type': 'int'},
        'meter_group_category_code': {'key': 'meterGroupCategoryCode', 'type': 'str'},
        'meter_group_category_info': {'key': 'meterGroupCategoryInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'number_of_groups': {'key': 'numberOfGroups', 'type': 'int'},
        'number_of_groups_with_visible_members': {'key': 'numberOfGroupsWithVisibleMembers', 'type': 'int'},
    }

    def __init__(self, *, meter_group_category_id: int=None, meter_group_category_code: str=None, meter_group_category_info: str=None, auto_group: bool=None, number_of_groups: int=None, number_of_groups_with_visible_members: int=None, **kwargs) -> None:
        super(MeterCategoryResponse, self).__init__(**kwargs)
        self.meter_group_category_id = meter_group_category_id
        self.meter_group_category_code = meter_group_category_code
        self.meter_group_category_info = meter_group_category_info
        self.auto_group = auto_group
        self.number_of_groups = number_of_groups
        self.number_of_groups_with_visible_members = number_of_groups_with_visible_members



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorResponse(Model):
    """GHGFactorResponse.

    :param factor_id: The factor identifier
    :type factor_id: int
    :param factor_code: The factor code
    :type factor_code: str
    :param factor_info: The factor info
    :type factor_info: str
    :param factor_description: The factor description
    :type factor_description: str
    :param source_organization: The source organization
    :type source_organization: str
    :param model: The model
    :type model: str
    :param factor_category:
    :type factor_category: ~energycap.sdk.models.GHGFactorCategory
    :param from_unit:
    :type from_unit: ~energycap.sdk.models.UnitChild
    :param factor_region:
    :type factor_region: ~energycap.sdk.models.GHGFactorRegion
    """

    _attribute_map = {
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_code': {'key': 'factorCode', 'type': 'str'},
        'factor_info': {'key': 'factorInfo', 'type': 'str'},
        'factor_description': {'key': 'factorDescription', 'type': 'str'},
        'source_organization': {'key': 'sourceOrganization', 'type': 'str'},
        'model': {'key': 'model', 'type': 'str'},
        'factor_category': {'key': 'factorCategory', 'type': 'GHGFactorCategory'},
        'from_unit': {'key': 'fromUnit', 'type': 'UnitChild'},
        'factor_region': {'key': 'factorRegion', 'type': 'GHGFactorRegion'},
    }

    def __init__(self, *, factor_id: int=None, factor_code: str=None, factor_info: str=None, factor_description: str=None, source_organization: str=None, model: str=None, factor_category=None, from_unit=None, factor_region=None, **kwargs) -> None:
        super(GHGFactorResponse, self).__init__(**kwargs)
        self.factor_id = factor_id
        self.factor_code = factor_code
        self.factor_info = factor_info
        self.factor_description = factor_description
        self.source_organization = source_organization
        self.model = model
        self.factor_category = factor_category
        self.from_unit = from_unit
        self.factor_region = factor_region



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGDefaultFactor(Model):
    """GHGDefaultFactor.

    All required parameters must be populated in order to send to Azure.

    :param factor_id: The Greenhouse Gas Factor identifier <span
     class='property-internal'>Required when FactorType is set to specific
     factor</span>
    :type factor_id: int
    :param factor_type: Required. The Greenhouse Gas Factor type.
     The valid values for this field are "use meter address" or "specific
     factor" <span class='property-internal'>Required</span> <span
     class='property-internal'>One of use meter address, specific factor
     </span>
    :type factor_type: str
    """

    _validation = {
        'factor_type': {'required': True},
    }

    _attribute_map = {
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'factor_type': {'key': 'factorType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGDefaultFactor, self).__init__(**kwargs)
        self.factor_id = kwargs.get('factor_id', None)
        self.factor_type = kwargs.get('factor_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapWidgetResponse(Model):
    """MapWidgetResponse.

    :param start_period: The start period for intensity data on places
    :type start_period: int
    :param end_period: The end period for intensity data on places
    :type end_period: int
    :param energy_use_intensity_unit:
    :type energy_use_intensity_unit: ~energycap.sdk.models.UnitChild
    :param energy_cost_intensity_unit:
    :type energy_cost_intensity_unit: ~energycap.sdk.models.UnitChild
    :param ghg_intensity_unit:
    :type ghg_intensity_unit: ~energycap.sdk.models.UnitChild
    :param floor_area_unit:
    :type floor_area_unit: ~energycap.sdk.models.UnitChild
    :param places: Place data to draw on the map
    :type places: list[~energycap.sdk.models.MapPlaceChild]
    """

    _attribute_map = {
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'energy_use_intensity_unit': {'key': 'energyUseIntensityUnit', 'type': 'UnitChild'},
        'energy_cost_intensity_unit': {'key': 'energyCostIntensityUnit', 'type': 'UnitChild'},
        'ghg_intensity_unit': {'key': 'ghgIntensityUnit', 'type': 'UnitChild'},
        'floor_area_unit': {'key': 'floorAreaUnit', 'type': 'UnitChild'},
        'places': {'key': 'places', 'type': '[MapPlaceChild]'},
    }

    def __init__(self, *, start_period: int=None, end_period: int=None, energy_use_intensity_unit=None, energy_cost_intensity_unit=None, ghg_intensity_unit=None, floor_area_unit=None, places=None, **kwargs) -> None:
        super(MapWidgetResponse, self).__init__(**kwargs)
        self.start_period = start_period
        self.end_period = end_period
        self.energy_use_intensity_unit = energy_use_intensity_unit
        self.energy_cost_intensity_unit = energy_cost_intensity_unit
        self.ghg_intensity_unit = ghg_intensity_unit
        self.floor_area_unit = floor_area_unit
        self.places = places



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGPerformanceComparison(Model):
    """GHGPerformanceComparison.

    :param type: The record type
    :type type: str
    :param id: The performance comparison identifier
    :type id: int
    :param label: The label
    :type label: str
    :param current_use: The current use
    :type current_use: float
    :param current_cost: The current cost
    :type current_cost: float
    :param current_emissions: The current emissions
    :type current_emissions: float
    :param previous_use: The previous use
    :type previous_use: float
    :param previous_cost: The previous cost
    :type previous_cost: float
    :param previous_emissions: The previous emissions
    :type previous_emissions: float
    :param use_percent_diff: The use KPI variance
    :type use_percent_diff: float
    :param cost_percent_diff: The cost KPI variance
    :type cost_percent_diff: float
    :param emissions_percent_diff: The emission KPI variance
    :type emissions_percent_diff: float
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param emissions_unit:
    :type emissions_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'label': {'key': 'label', 'type': 'str'},
        'current_use': {'key': 'currentUse', 'type': 'float'},
        'current_cost': {'key': 'currentCost', 'type': 'float'},
        'current_emissions': {'key': 'currentEmissions', 'type': 'float'},
        'previous_use': {'key': 'previousUse', 'type': 'float'},
        'previous_cost': {'key': 'previousCost', 'type': 'float'},
        'previous_emissions': {'key': 'previousEmissions', 'type': 'float'},
        'use_percent_diff': {'key': 'usePercentDiff', 'type': 'float'},
        'cost_percent_diff': {'key': 'costPercentDiff', 'type': 'float'},
        'emissions_percent_diff': {'key': 'emissionsPercentDiff', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'emissions_unit': {'key': 'emissionsUnit', 'type': 'UnitChild'},
    }

    def __init__(self, *, type: str=None, id: int=None, label: str=None, current_use: float=None, current_cost: float=None, current_emissions: float=None, previous_use: float=None, previous_cost: float=None, previous_emissions: float=None, use_percent_diff: float=None, cost_percent_diff: float=None, emissions_percent_diff: float=None, use_unit=None, emissions_unit=None, **kwargs) -> None:
        super(GHGPerformanceComparison, self).__init__(**kwargs)
        self.type = type
        self.id = id
        self.label = label
        self.current_use = current_use
        self.current_cost = current_cost
        self.current_emissions = current_emissions
        self.previous_use = previous_use
        self.previous_cost = previous_cost
        self.previous_emissions = previous_emissions
        self.use_percent_diff = use_percent_diff
        self.cost_percent_diff = cost_percent_diff
        self.emissions_percent_diff = emissions_percent_diff
        self.use_unit = use_unit
        self.emissions_unit = emissions_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyCapOptionsEnergyCapIDOptions(Model):
    """EnergyCapOptionsEnergyCapIDOptions.

    :param base_url:
    :type base_url: str
    :param gateway_api_path:
    :type gateway_api_path: str
    """

    _attribute_map = {
        'base_url': {'key': 'baseUrl', 'type': 'str'},
        'gateway_api_path': {'key': 'gatewayApiPath', 'type': 'str'},
    }

    def __init__(self, *, base_url: str=None, gateway_api_path: str=None, **kwargs) -> None:
        super(EnergyCapOptionsEnergyCapIDOptions, self).__init__(**kwargs)
        self.base_url = base_url
        self.gateway_api_path = gateway_api_path



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedComparisonResponseGHGPerformanceComparison(Model):
    """AggregatedComparisonResponseGHGPerformanceComparison.

    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRangeComparison
    :param total:
    :type total: ~energycap.sdk.models.GHGPerformanceComparison
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.GHGPerformanceComparison]
    """

    _attribute_map = {
        'period_range': {'key': 'periodRange', 'type': 'PeriodRangeComparison'},
        'total': {'key': 'total', 'type': 'GHGPerformanceComparison'},
        'data_details': {'key': 'dataDetails', 'type': '[GHGPerformanceComparison]'},
    }

    def __init__(self, *, period_range=None, total=None, data_details=None, **kwargs) -> None:
        super(AggregatedComparisonResponseGHGPerformanceComparison, self).__init__(**kwargs)
        self.period_range = period_range
        self.total = total
        self.data_details = data_details



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingImportProfileColumn(Model):
    """ReadingImportProfileColumn.

    All required parameters must be populated in order to send to Azure.

    :param column_number: The number of the column <span
     class='property-internal'>Must be between 1 and 2147483647</span>
    :type column_number: int
    :param observation_type_code: Required. The observation type code of the
     reading <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type observation_type_code: str
    :param unit_code: Required. The unit code of the reading <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type unit_code: str
    """

    _validation = {
        'column_number': {'maximum': 2147483647, 'minimum': 1},
        'observation_type_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'unit_code': {'required': True, 'max_length': 16, 'min_length': 0},
    }

    _attribute_map = {
        'column_number': {'key': 'columnNumber', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReadingImportProfileColumn, self).__init__(**kwargs)
        self.column_number = kwargs.get('column_number', None)
        self.observation_type_code = kwargs.get('observation_type_code', None)
        self.unit_code = kwargs.get('unit_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceEdit(Model):
    """EmissionSourceEdit.

    All required parameters must be populated in order to send to Azure.

    :param active: Required. Is the emission source active <span
     class='property-internal'>Required</span>
    :type active: bool
    :param emission_source_code: Required. The emission source code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type emission_source_code: str
    :param emission_source_info: Required. The emission source info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type emission_source_info: str
    :param commodity_id: Required. The emission source's commodity <span
     class='property-internal'>Required</span>
    :type commodity_id: int
    :param collection_id: Required. The collection to which the emission
     source belongs <span class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Collection)</span>
    :type collection_id: int
    :param default_scope_category_id: Required. The default scope category for
     the emission source <span class='property-internal'>Required</span>
    :type default_scope_category_id: int
    :param default_emission_factor: Required.
    :type default_emission_factor: ~energycap.sdk.models.GHGDefaultFactor
    :param note: The emission source note <span class='property-internal'>Must
     be between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChildBase
    """

    _validation = {
        'active': {'required': True},
        'emission_source_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'emission_source_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'commodity_id': {'required': True},
        'collection_id': {'required': True},
        'default_scope_category_id': {'required': True},
        'default_emission_factor': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'active': {'key': 'active', 'type': 'bool'},
        'emission_source_code': {'key': 'emissionSourceCode', 'type': 'str'},
        'emission_source_info': {'key': 'emissionSourceInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'collection_id': {'key': 'collectionId', 'type': 'int'},
        'default_scope_category_id': {'key': 'defaultScopeCategoryId', 'type': 'int'},
        'default_emission_factor': {'key': 'defaultEmissionFactor', 'type': 'GHGDefaultFactor'},
        'note': {'key': 'note', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChildBase'},
    }

    def __init__(self, *, active: bool, emission_source_code: str, emission_source_info: str, commodity_id: int, collection_id: int, default_scope_category_id: int, default_emission_factor, note: str=None, address=None, **kwargs) -> None:
        super(EmissionSourceEdit, self).__init__(**kwargs)
        self.active = active
        self.emission_source_code = emission_source_code
        self.emission_source_info = emission_source_info
        self.commodity_id = commodity_id
        self.collection_id = collection_id
        self.default_scope_category_id = default_scope_category_id
        self.default_emission_factor = default_emission_factor
        self.note = note
        self.address = address



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchSettings(Model):
    """BatchSettings.

    :param batch_mode: needs to be one of - "use existing batch", "new batch",
     "new self-contained batch", "use pending batch"
     if "use existing" - we will use an existing open batch and leave it open
     if "new batch" - close existing open batch and  make a new batch
     if "new self-contained batch" - make a new batch and add bills to it and
     close it. Any open batch will be left open
     if "use pending batch" - PendingBatchId is required.  We will use the
     pending batch and leave it pending <span class='property-internal'>One of
     use existing batch, new batch, new self-contained batch, use pending batch
     </span>
    :type batch_mode: str
    :param pending_batch_id: Pending batchId to import the bills into <span
     class='property-internal'>Required when BatchMode is set to use pending
     batch</span>
    :type pending_batch_id: int
    :param new_batch_code: optional- if not provided, we will autocreate the
     batch code.
     If useExistingBatch is true, this value will be ignored <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type new_batch_code: str
    """

    _validation = {
        'new_batch_code': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_mode': {'key': 'batchMode', 'type': 'str'},
        'pending_batch_id': {'key': 'pendingBatchId', 'type': 'int'},
        'new_batch_code': {'key': 'newBatchCode', 'type': 'str'},
    }

    def __init__(self, *, batch_mode: str=None, pending_batch_id: int=None, new_batch_code: str=None, **kwargs) -> None:
        super(BatchSettings, self).__init__(**kwargs)
        self.batch_mode = batch_mode
        self.pending_batch_id = pending_batch_id
        self.new_batch_code = new_batch_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGScopeCategory(Model):
    """GHGScopeCategory.

    :param scope:
    :type scope: ~energycap.sdk.models.GHGScope
    :param scope_category_id: The GHG Scope Category Identifier
    :type scope_category_id: int
    :param scope_category_info: The GHG Scope Category Info
    :type scope_category_info: str
    :param scope_category_description: The GHG Scope Category Description
    :type scope_category_description: str
    """

    _attribute_map = {
        'scope': {'key': 'scope', 'type': 'GHGScope'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
        'scope_category_info': {'key': 'scopeCategoryInfo', 'type': 'str'},
        'scope_category_description': {'key': 'scopeCategoryDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GHGScopeCategory, self).__init__(**kwargs)
        self.scope = kwargs.get('scope', None)
        self.scope_category_id = kwargs.get('scope_category_id', None)
        self.scope_category_info = kwargs.get('scope_category_info', None)
        self.scope_category_description = kwargs.get('scope_category_description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsSiteRequest(Model):
    """WatticsSiteRequest.

    :param wattics_site_id: The identifier for a Wattics site
     Set to null to remove the link <span class='property-internal'>Required
     (defined)</span>
    :type wattics_site_id: int
    """

    _attribute_map = {
        'wattics_site_id': {'key': 'watticsSiteId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(WatticsSiteRequest, self).__init__(**kwargs)
        self.wattics_site_id = kwargs.get('wattics_site_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterResponse(Model):
    """MeterResponse.

    :param meter_id: The identifier for the meter
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_type:
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param channels: An array of channels assigned to this meter
    :type channels: list[~energycap.sdk.models.ChannelChild]
    :param accounts:
    :type accounts: list[~energycap.sdk.models.MeterAccountChild]
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the building is included in
     ENERGY STAR submissions
    :type include_in_energy_star: bool
    :param primary_use:
    :type primary_use: ~energycap.sdk.models.PrimaryUseChild
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the meter was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification of
     the meter
    :type modified_date: datetime
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param include_in_cost_avoidance: Indicates if the meter should be
     included in cost avoidance
    :type include_in_cost_avoidance: bool
    :param route:
    :type route: ~energycap.sdk.models.RouteChild
    :param meter_time_zone:
    :type meter_time_zone: ~energycap.sdk.models.TimeZoneChild
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param demand_unit:
    :type demand_unit: ~energycap.sdk.models.UnitChild
    :param serial_number: Meter's currently assigned serial number
    :type serial_number: str
    :param serial_number_history:
    :type serial_number_history:
     ~energycap.sdk.models.MeterSerialNumberHistoryChild
    :param meter_description: A description of the meter
    :type meter_description: str
    :param wattics_data_point:
    :type wattics_data_point: ~energycap.sdk.models.WatticsDataPoint
    :param emission_source:
    :type emission_source: ~energycap.sdk.models.EmissionSourceLink
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'channels': {'key': 'channels', 'type': '[ChannelChild]'},
        'accounts': {'key': 'accounts', 'type': '[MeterAccountChild]'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'primary_use': {'key': 'primaryUse', 'type': 'PrimaryUseChild'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'include_in_cost_avoidance': {'key': 'includeInCostAvoidance', 'type': 'bool'},
        'route': {'key': 'route', 'type': 'RouteChild'},
        'meter_time_zone': {'key': 'meterTimeZone', 'type': 'TimeZoneChild'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'demand_unit': {'key': 'demandUnit', 'type': 'UnitChild'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
        'serial_number_history': {'key': 'serialNumberHistory', 'type': 'MeterSerialNumberHistoryChild'},
        'meter_description': {'key': 'meterDescription', 'type': 'str'},
        'wattics_data_point': {'key': 'watticsDataPoint', 'type': 'WatticsDataPoint'},
        'emission_source': {'key': 'emissionSource', 'type': 'EmissionSourceLink'},
    }

    def __init__(self, **kwargs):
        super(MeterResponse, self).__init__(**kwargs)
        self.meter_id = kwargs.get('meter_id', None)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.meter_type = kwargs.get('meter_type', None)
        self.channels = kwargs.get('channels', None)
        self.accounts = kwargs.get('accounts', None)
        self.commodity = kwargs.get('commodity', None)
        self.place = kwargs.get('place', None)
        self.address = kwargs.get('address', None)
        self.bill_entry_note = kwargs.get('bill_entry_note', None)
        self.include_in_energy_star = kwargs.get('include_in_energy_star', None)
        self.primary_use = kwargs.get('primary_use', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.modified_date = kwargs.get('modified_date', None)
        self.properties = kwargs.get('properties', None)
        self.include_in_cost_avoidance = kwargs.get('include_in_cost_avoidance', None)
        self.route = kwargs.get('route', None)
        self.meter_time_zone = kwargs.get('meter_time_zone', None)
        self.active = kwargs.get('active', None)
        self.is_calculated_meter = kwargs.get('is_calculated_meter', None)
        self.is_split_parent_meter = kwargs.get('is_split_parent_meter', None)
        self.is_split_child_meter = kwargs.get('is_split_child_meter', None)
        self.use_unit = kwargs.get('use_unit', None)
        self.demand_unit = kwargs.get('demand_unit', None)
        self.serial_number = kwargs.get('serial_number', None)
        self.serial_number_history = kwargs.get('serial_number_history', None)
        self.meter_description = kwargs.get('meter_description', None)
        self.wattics_data_point = kwargs.get('wattics_data_point', None)
        self.emission_source = kwargs.get('emission_source', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestComparisonResponse(Model):
    """Comparison data for a place.

    :param current_period_range:
    :type current_period_range: ~energycap.sdk.models.PeriodRange
    :param previous_period_range:
    :type previous_period_range: ~energycap.sdk.models.PeriodRange
    :param intensity:
    :type intensity: ~energycap.sdk.models.ValueComparison
    :param total:
    :type total: ~energycap.sdk.models.ValueComparison
    :param commodities: Comparison values for each commodity
    :type commodities: list[~energycap.sdk.models.CommodityValueComparison]
    :param floor_area_unit:
    :type floor_area_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'current_period_range': {'key': 'currentPeriodRange', 'type': 'PeriodRange'},
        'previous_period_range': {'key': 'previousPeriodRange', 'type': 'PeriodRange'},
        'intensity': {'key': 'intensity', 'type': 'ValueComparison'},
        'total': {'key': 'total', 'type': 'ValueComparison'},
        'commodities': {'key': 'commodities', 'type': '[CommodityValueComparison]'},
        'floor_area_unit': {'key': 'floorAreaUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestComparisonResponse, self).__init__(**kwargs)
        self.current_period_range = kwargs.get('current_period_range', None)
        self.previous_period_range = kwargs.get('previous_period_range', None)
        self.intensity = kwargs.get('intensity', None)
        self.total = kwargs.get('total', None)
        self.commodities = kwargs.get('commodities', None)
        self.floor_area_unit = kwargs.get('floor_area_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesDataResponse(Model):
    """TimeSeriesDataResponse.

    :param entities:
    :type entities: list[~energycap.sdk.models.TimeSeriesEntity]
    :param values:
    :type values: list[~energycap.sdk.models.TimeSeriesValue]
    """

    _attribute_map = {
        'entities': {'key': 'entities', 'type': '[TimeSeriesEntity]'},
        'values': {'key': 'values', 'type': '[TimeSeriesValue]'},
    }

    def __init__(self, *, entities=None, values=None, **kwargs) -> None:
        super(TimeSeriesDataResponse, self).__init__(**kwargs)
        self.entities = entities
        self.values = values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterEdit(Model):
    """MeterEdit.

    All required parameters must be populated in order to send to Azure.

    :param meter_code: Required. The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: Required. The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param place_id: Required. The identifier for the place the meter is
     assigned to <span class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param commodity_id: Required. The commodity identifier that the meter is
     assigned to.
     If different from original commodity id, then a commodity change will be
     attempted. <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note <span
     class='property-internal'>Must be between 0 and 64 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type bill_entry_note: str
    :param include_in_energy_star: DEPRECATED
     To be included in ENERGY STAR a meter needs to be linked to a meter in
     Portfolio Manager
     This can be done with the PUT place/{placeId}/energyStar/link or the
     ENERGY STAR: Mappings Setup Sheet <span class='property-internal'>Required
     (defined)</span>
    :type include_in_energy_star: bool
    :param primary_use_id: The identifier for the meter's primary use <span
     class='property-internal'>Required (defined)</span>
    :type primary_use_id: int
    :param meter_time_zone_id: Required. The identifier for the meter's time
     zone. <span class='property-internal'>Required</span>
    :type meter_time_zone_id: int
    :param active: Required. Is this meter active? <span
     class='property-internal'>Required</span>
    :type active: bool
    :param properties: An array of meter properties <span
     class='property-internal'>Required (defined)</span>
    :type properties: dict[str, str]
    :param use_unit_id: The use unit ID is the reporting unit for use for this
     meter.
     If it is null the use unit will be removed <span
     class='property-internal'>Required (defined)</span>
    :type use_unit_id: int
    :param demand_unit_id: The demand unit ID is the reporting unit for demand
     for this meter.
     If it is null the demand unit will be removed <span
     class='property-internal'>Required (defined)</span>
    :type demand_unit_id: int
    :param meter_description: A description of the meter <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
     <span class='property-internal'>Required (defined)</span>. Default value:
     "Æ" .
    :type meter_description: str
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'place_id': {'required': True},
        'commodity_id': {'required': True},
        'bill_entry_note': {'max_length': 64, 'min_length': 0},
        'meter_time_zone_id': {'required': True},
        'active': {'required': True},
        'meter_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'meter_time_zone_id': {'key': 'meterTimeZoneId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
        'meter_description': {'key': 'meterDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeterEdit, self).__init__(**kwargs)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.place_id = kwargs.get('place_id', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.address = kwargs.get('address', None)
        self.bill_entry_note = kwargs.get('bill_entry_note', None)
        self.include_in_energy_star = kwargs.get('include_in_energy_star', None)
        self.primary_use_id = kwargs.get('primary_use_id', None)
        self.meter_time_zone_id = kwargs.get('meter_time_zone_id', None)
        self.active = kwargs.get('active', None)
        self.properties = kwargs.get('properties', None)
        self.use_unit_id = kwargs.get('use_unit_id', None)
        self.demand_unit_id = kwargs.get('demand_unit_id', None)
        self.meter_description = kwargs.get('meter_description', "Æ")



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityResponse(Model):
    """CommodityResponse.

    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param abbreviation: Three letter abbreviation code to represent the
     commodity
    :type abbreviation: str
    :param description: The commodity description
    :type description: str
    :param icon:
    :type icon: ~energycap.sdk.models.Icon
    :param commodity_category:
    :type commodity_category: ~energycap.sdk.models.CommodityCategory
    :param use_rollup_unit:
    :type use_rollup_unit: ~energycap.sdk.models.UnitChild
    :param demand_rollup_unit:
    :type demand_rollup_unit: ~energycap.sdk.models.UnitChild
    :param include_in_energy_reporting: Indicates if the commodity should be
     included in Energy reporting
    :type include_in_energy_reporting: bool
    :param energy_reporting_unit_conversion_multiplier: The multiplier to
     convert from the commodity rollup unit to the energy use reporting unit
    :type energy_reporting_unit_conversion_multiplier: float
    :param in_use: Indicates if the commodity is in use on a meter
    :type in_use: bool
    :param is_system_commodity: Indicates if the commodity is a system-level
     commodity
    :type is_system_commodity: bool
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'abbreviation': {'key': 'abbreviation', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'icon': {'key': 'icon', 'type': 'Icon'},
        'commodity_category': {'key': 'commodityCategory', 'type': 'CommodityCategory'},
        'use_rollup_unit': {'key': 'useRollupUnit', 'type': 'UnitChild'},
        'demand_rollup_unit': {'key': 'demandRollupUnit', 'type': 'UnitChild'},
        'include_in_energy_reporting': {'key': 'includeInEnergyReporting', 'type': 'bool'},
        'energy_reporting_unit_conversion_multiplier': {'key': 'energyReportingUnitConversionMultiplier', 'type': 'float'},
        'in_use': {'key': 'inUse', 'type': 'bool'},
        'is_system_commodity': {'key': 'isSystemCommodity', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(CommodityResponse, self).__init__(**kwargs)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.description = kwargs.get('description', None)
        self.icon = kwargs.get('icon', None)
        self.commodity_category = kwargs.get('commodity_category', None)
        self.use_rollup_unit = kwargs.get('use_rollup_unit', None)
        self.demand_rollup_unit = kwargs.get('demand_rollup_unit', None)
        self.include_in_energy_reporting = kwargs.get('include_in_energy_reporting', None)
        self.energy_reporting_unit_conversion_multiplier = kwargs.get('energy_reporting_unit_conversion_multiplier', None)
        self.in_use = kwargs.get('in_use', None)
        self.is_system_commodity = kwargs.get('is_system_commodity', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGGroupEmissions(Model):
    """GHGGroupEmissions.

    :param group_info: The name of the greenhouse gas.
    :type group_info: str
    :param total_emissions: The total emissions for this gas, in CO2
     Equivalent.
    :type total_emissions: float
    """

    _attribute_map = {
        'group_info': {'key': 'groupInfo', 'type': 'str'},
        'total_emissions': {'key': 'totalEmissions', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(GHGGroupEmissions, self).__init__(**kwargs)
        self.group_info = kwargs.get('group_info', None)
        self.total_emissions = kwargs.get('total_emissions', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsMonthlyResponseResults(Model):
    """PlaceDigestSavingsMonthlyResponseResults.

    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param savings_total_cost: Savings Total Cost
    :type savings_total_cost: float
    :param savings_global_use: Savings Global Use
    :type savings_global_use: float
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'savings_total_cost': {'key': 'savingsTotalCost', 'type': 'float'},
        'savings_global_use': {'key': 'savingsGlobalUse', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestSavingsMonthlyResponseResults, self).__init__(**kwargs)
        self.period_name = kwargs.get('period_name', None)
        self.calendar_period = kwargs.get('calendar_period', None)
        self.calendar_year = kwargs.get('calendar_year', None)
        self.fiscal_period = kwargs.get('fiscal_period', None)
        self.fiscal_year = kwargs.get('fiscal_year', None)
        self.savings_total_cost = kwargs.get('savings_total_cost', None)
        self.savings_global_use = kwargs.get('savings_global_use', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodRangeComparisonDetailed(Model):
    """PeriodRangeComparisonDetailed.

    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.PeriodComparison]
    :param current_period_range:
    :type current_period_range: ~energycap.sdk.models.PeriodRange
    :param previous_period_range:
    :type previous_period_range: ~energycap.sdk.models.PeriodRange
    :param current_value:
    :type current_value: ~energycap.sdk.models.ValueWithUnit
    :param previous_value:
    :type previous_value: ~energycap.sdk.models.ValueWithUnit
    """

    _attribute_map = {
        'data_details': {'key': 'dataDetails', 'type': '[PeriodComparison]'},
        'current_period_range': {'key': 'currentPeriodRange', 'type': 'PeriodRange'},
        'previous_period_range': {'key': 'previousPeriodRange', 'type': 'PeriodRange'},
        'current_value': {'key': 'currentValue', 'type': 'ValueWithUnit'},
        'previous_value': {'key': 'previousValue', 'type': 'ValueWithUnit'},
    }

    def __init__(self, *, data_details=None, current_period_range=None, previous_period_range=None, current_value=None, previous_value=None, **kwargs) -> None:
        super(PeriodRangeComparisonDetailed, self).__init__(**kwargs)
        self.data_details = data_details
        self.current_period_range = current_period_range
        self.previous_period_range = previous_period_range
        self.current_value = current_value
        self.previous_value = previous_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CollectionResponse(Model):
    """CollectionResponse.

    :param collection_id: The collection identifier
    :type collection_id: int
    :param collection_code: The collection code
    :type collection_code: str
    :param collection_info: The collection info
    :type collection_info: str
    :param note: The collection description
    :type note: str
    :param collection_icon:
    :type collection_icon: ~energycap.sdk.models.Icon
    :param parent:
    :type parent: ~energycap.sdk.models.CollectionChild
    :param collections: An array of child collections
    :type collections: list[~energycap.sdk.models.CollectionChild]
    :param emission_sources: An array of child emission sources
    :type emission_sources:
     list[~energycap.sdk.models.CollectionEmissionSourceChild]
    """

    _attribute_map = {
        'collection_id': {'key': 'collectionId', 'type': 'int'},
        'collection_code': {'key': 'collectionCode', 'type': 'str'},
        'collection_info': {'key': 'collectionInfo', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'collection_icon': {'key': 'collectionIcon', 'type': 'Icon'},
        'parent': {'key': 'parent', 'type': 'CollectionChild'},
        'collections': {'key': 'collections', 'type': '[CollectionChild]'},
        'emission_sources': {'key': 'emissionSources', 'type': '[CollectionEmissionSourceChild]'},
    }

    def __init__(self, *, collection_id: int=None, collection_code: str=None, collection_info: str=None, note: str=None, collection_icon=None, parent=None, collections=None, emission_sources=None, **kwargs) -> None:
        super(CollectionResponse, self).__init__(**kwargs)
        self.collection_id = collection_id
        self.collection_code = collection_code
        self.collection_info = collection_info
        self.note = note
        self.collection_icon = collection_icon
        self.parent = parent
        self.collections = collections
        self.emission_sources = emission_sources



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PermissionProduct(Model):
    """PermissionProduct.

    :param product_id:
    :type product_id: int
    :param product_code:
    :type product_code: str
    :param product_info:
    :type product_info: str
    """

    _attribute_map = {
        'product_id': {'key': 'productId', 'type': 'int'},
        'product_code': {'key': 'productCode', 'type': 'str'},
        'product_info': {'key': 'productInfo', 'type': 'str'},
    }

    def __init__(self, *, product_id: int=None, product_code: str=None, product_info: str=None, **kwargs) -> None:
        super(PermissionProduct, self).__init__(**kwargs)
        self.product_id = product_id
        self.product_code = product_code
        self.product_info = product_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagActionChild(Model):
    """FlagActionChild.

    :param flag_action_id: The flag action identifier
    :type flag_action_id: int
    :param flag_action_info: Flag action information
    :type flag_action_info: str
    """

    _attribute_map = {
        'flag_action_id': {'key': 'flagActionId', 'type': 'int'},
        'flag_action_info': {'key': 'flagActionInfo', 'type': 'str'},
    }

    def __init__(self, *, flag_action_id: int=None, flag_action_info: str=None, **kwargs) -> None:
        super(FlagActionChild, self).__init__(**kwargs)
        self.flag_action_id = flag_action_id
        self.flag_action_info = flag_action_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TopmostCollection(Model):
    """TopmostCollection.

    :param is_multi_topmost_collection: User's topmost combines multiple
     collections
    :type is_multi_topmost_collection: bool
    :param multi_topmost_collections:
    :type multi_topmost_collections:
     list[~energycap.sdk.models.CollectionChild]
    :param collection_id: The collection identifier
    :type collection_id: int
    :param collection_code: The collection code
    :type collection_code: str
    :param collection_info: The collection info
    :type collection_info: str
    :param collection_icon:
    :type collection_icon: ~energycap.sdk.models.Icon
    """

    _attribute_map = {
        'is_multi_topmost_collection': {'key': 'isMultiTopmostCollection', 'type': 'bool'},
        'multi_topmost_collections': {'key': 'multiTopmostCollections', 'type': '[CollectionChild]'},
        'collection_id': {'key': 'collectionId', 'type': 'int'},
        'collection_code': {'key': 'collectionCode', 'type': 'str'},
        'collection_info': {'key': 'collectionInfo', 'type': 'str'},
        'collection_icon': {'key': 'collectionIcon', 'type': 'Icon'},
    }

    def __init__(self, *, is_multi_topmost_collection: bool=None, multi_topmost_collections=None, collection_id: int=None, collection_code: str=None, collection_info: str=None, collection_icon=None, **kwargs) -> None:
        super(TopmostCollection, self).__init__(**kwargs)
        self.is_multi_topmost_collection = is_multi_topmost_collection
        self.multi_topmost_collections = multi_topmost_collections
        self.collection_id = collection_id
        self.collection_code = collection_code
        self.collection_info = collection_info
        self.collection_icon = collection_icon



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportingSettingResponse(Model):
    """ReportingSettingResponse.

    :param energy_unit:
    :type energy_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param floor_area_unit:
    :type floor_area_unit: ~energycap.sdk.models.UnitChild
    :param months_to_exclude_from_charts: Months to exclude from charts,
     including the current month.
     Ex. If the current month is October,
     A value of 0 will not exclude any months,
     A value of 1 will exclude the month of October,
     A value of 2 will exclude October and September,
     A value of 3 will exclude October, September, and August,
     A value of 13 will exclude October and the last full year of data.
    :type months_to_exclude_from_charts: int
    """

    _attribute_map = {
        'energy_unit': {'key': 'energyUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'floor_area_unit': {'key': 'floorAreaUnit', 'type': 'UnitChild'},
        'months_to_exclude_from_charts': {'key': 'monthsToExcludeFromCharts', 'type': 'int'},
    }

    def __init__(self, *, energy_unit=None, cost_unit=None, floor_area_unit=None, months_to_exclude_from_charts: int=None, **kwargs) -> None:
        super(ReportingSettingResponse, self).__init__(**kwargs)
        self.energy_unit = energy_unit
        self.cost_unit = cost_unit
        self.floor_area_unit = floor_area_unit
        self.months_to_exclude_from_charts = months_to_exclude_from_charts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityValueComparison(Model):
    """General purpose commodity value comparison DTO.

    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param current_value:
    :type current_value: ~energycap.sdk.models.ValueWithUnit
    :param previous_value:
    :type previous_value: ~energycap.sdk.models.ValueWithUnit
    """

    _attribute_map = {
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'current_value': {'key': 'currentValue', 'type': 'ValueWithUnit'},
        'previous_value': {'key': 'previousValue', 'type': 'ValueWithUnit'},
    }

    def __init__(self, **kwargs):
        super(CommodityValueComparison, self).__init__(**kwargs)
        self.commodity = kwargs.get('commodity', None)
        self.current_value = kwargs.get('current_value', None)
        self.previous_value = kwargs.get('previous_value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchicalCollections(Model):
    """HierarchicalCollections.

    :param parent_id: The collection's parent
    :type parent_id: int
    :param collection_id: The collection's primary ID
    :type collection_id: int
    :param collection_info: The collection info
    :type collection_info: str
    :param collection_code: The collection code
    :type collection_code: str
    :param collection_icon:
    :type collection_icon: ~energycap.sdk.models.Icon
    :param has_children: If this collection has any children, either emission
     sources or collections
    :type has_children: bool
    :param has_collection_children: If this collection has any collection
     children
    :type has_collection_children: bool
    :param has_emission_source_children: If this collection has any emission
     source children
    :type has_emission_source_children: bool
    :param has_active_children: If this collection has any collection children
     or active emission source children
    :type has_active_children: bool
    :param has_active_emission_source_children: If this collection has any
     active emission source children
    :type has_active_emission_source_children: bool
    :param emission_source_children: List of emission source children
    :type emission_source_children:
     list[~energycap.sdk.models.CollectionEmissionSourceChild]
    :param collection_children: List of collection children
    :type collection_children:
     list[~energycap.sdk.models.HierarchicalCollections2]
    """

    _attribute_map = {
        'parent_id': {'key': 'parentId', 'type': 'int'},
        'collection_id': {'key': 'collectionId', 'type': 'int'},
        'collection_info': {'key': 'collectionInfo', 'type': 'str'},
        'collection_code': {'key': 'collectionCode', 'type': 'str'},
        'collection_icon': {'key': 'collectionIcon', 'type': 'Icon'},
        'has_children': {'key': 'hasChildren', 'type': 'bool'},
        'has_collection_children': {'key': 'hasCollectionChildren', 'type': 'bool'},
        'has_emission_source_children': {'key': 'hasEmissionSourceChildren', 'type': 'bool'},
        'has_active_children': {'key': 'hasActiveChildren', 'type': 'bool'},
        'has_active_emission_source_children': {'key': 'hasActiveEmissionSourceChildren', 'type': 'bool'},
        'emission_source_children': {'key': 'emissionSourceChildren', 'type': '[CollectionEmissionSourceChild]'},
        'collection_children': {'key': 'collectionChildren', 'type': '[HierarchicalCollections2]'},
    }

    def __init__(self, **kwargs):
        super(HierarchicalCollections, self).__init__(**kwargs)
        self.parent_id = kwargs.get('parent_id', None)
        self.collection_id = kwargs.get('collection_id', None)
        self.collection_info = kwargs.get('collection_info', None)
        self.collection_code = kwargs.get('collection_code', None)
        self.collection_icon = kwargs.get('collection_icon', None)
        self.has_children = kwargs.get('has_children', None)
        self.has_collection_children = kwargs.get('has_collection_children', None)
        self.has_emission_source_children = kwargs.get('has_emission_source_children', None)
        self.has_active_children = kwargs.get('has_active_children', None)
        self.has_active_emission_source_children = kwargs.get('has_active_emission_source_children', None)
        self.emission_source_children = kwargs.get('emission_source_children', None)
        self.collection_children = kwargs.get('collection_children', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionRecordResponse(Model):
    """EmissionRecordResponse.

    :param emission_record_id: The record identifier
    :type emission_record_id: int
    :param bill_id: The bill identifier, if this record originated from a bill
     in UtilityManagement
    :type bill_id: int
    :param emission_source:
    :type emission_source: ~energycap.sdk.models.EmissionSourceChild
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param start_date: The start date for the record
    :type start_date: datetime
    :param end_date: The end date for the record
    :type end_date: datetime
    :param billing_period: The bill's billing period, if this record
     originated from a bill in UtilityManagement
    :type billing_period: int
    :param emission_record_type:
    :type emission_record_type: ~energycap.sdk.models.EmissionRecordType
    :param scope_category:
    :type scope_category: ~energycap.sdk.models.GHGScopeCategoryChild
    :param factor:
    :type factor: ~energycap.sdk.models.GHGFactorChild
    :param quantity:
    :type quantity: ~energycap.sdk.models.ValueWithUnit
    :param cost:
    :type cost: ~energycap.sdk.models.ValueWithUnit
    :param total_emissions: The total GHG emissions for this record in kgCO2e.
    :type total_emissions: float
    :param emission_values: The GHG emissions for this record, split by
     greenhouse gas type
    :type emission_values: list[~energycap.sdk.models.GHGGroupEmissions]
    :param note: The note for this record
    :type note: str
    :param attachment: The attachment for this record
    :type attachment: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date this record was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date this record was last modified
    :type modified_date: datetime
    :param creation_method: The emission record creation method
    :type creation_method: str
    """

    _attribute_map = {
        'emission_record_id': {'key': 'emissionRecordId', 'type': 'int'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'emission_source': {'key': 'emissionSource', 'type': 'EmissionSourceChild'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'emission_record_type': {'key': 'emissionRecordType', 'type': 'EmissionRecordType'},
        'scope_category': {'key': 'scopeCategory', 'type': 'GHGScopeCategoryChild'},
        'factor': {'key': 'factor', 'type': 'GHGFactorChild'},
        'quantity': {'key': 'quantity', 'type': 'ValueWithUnit'},
        'cost': {'key': 'cost', 'type': 'ValueWithUnit'},
        'total_emissions': {'key': 'totalEmissions', 'type': 'float'},
        'emission_values': {'key': 'emissionValues', 'type': '[GHGGroupEmissions]'},
        'note': {'key': 'note', 'type': 'str'},
        'attachment': {'key': 'attachment', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'creation_method': {'key': 'creationMethod', 'type': 'str'},
    }

    def __init__(self, *, emission_record_id: int=None, bill_id: int=None, emission_source=None, vendor=None, start_date=None, end_date=None, billing_period: int=None, emission_record_type=None, scope_category=None, factor=None, quantity=None, cost=None, total_emissions: float=None, emission_values=None, note: str=None, attachment: str=None, created_by=None, created_date=None, modified_by=None, modified_date=None, creation_method: str=None, **kwargs) -> None:
        super(EmissionRecordResponse, self).__init__(**kwargs)
        self.emission_record_id = emission_record_id
        self.bill_id = bill_id
        self.emission_source = emission_source
        self.vendor = vendor
        self.start_date = start_date
        self.end_date = end_date
        self.billing_period = billing_period
        self.emission_record_type = emission_record_type
        self.scope_category = scope_category
        self.factor = factor
        self.quantity = quantity
        self.cost = cost
        self.total_emissions = total_emissions
        self.emission_values = emission_values
        self.note = note
        self.attachment = attachment
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.creation_method = creation_method



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TargetSettings(Model):
    """TargetSettings.

    :param label: Target line label
    :type label: str
    :param base_year: Target line base year
    :type base_year: int
    :param cost_target:
    :type cost_target: ~energycap.sdk.models.Target
    :param use_target:
    :type use_target: ~energycap.sdk.models.Target
    :param ghg_target:
    :type ghg_target: ~energycap.sdk.models.Target
    """

    _attribute_map = {
        'label': {'key': 'label', 'type': 'str'},
        'base_year': {'key': 'baseYear', 'type': 'int'},
        'cost_target': {'key': 'costTarget', 'type': 'Target'},
        'use_target': {'key': 'useTarget', 'type': 'Target'},
        'ghg_target': {'key': 'ghgTarget', 'type': 'Target'},
    }

    def __init__(self, *, label: str=None, base_year: int=None, cost_target=None, use_target=None, ghg_target=None, **kwargs) -> None:
        super(TargetSettings, self).__init__(**kwargs)
        self.label = label
        self.base_year = base_year
        self.cost_target = cost_target
        self.use_target = use_target
        self.ghg_target = ghg_target



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Icon(Model):
    """Icon.

    :param code: The icon code <span class='property-internal'>Must be between
     0 and 64 characters</span>
    :type code: str
    :param color: The icon color <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type color: str
    """

    _validation = {
        'code': {'max_length': 64, 'min_length': 0},
        'color': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'color': {'key': 'color', 'type': 'str'},
    }

    def __init__(self, *, code: str=None, color: str=None, **kwargs) -> None:
        super(Icon, self).__init__(**kwargs)
        self.code = code
        self.color = color



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionMove(Model):
    """BillActionMove.

    :param ids: Ids of bills to be moved <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type ids: list[int]
    :param account_id: Destination Account Id <span
     class='property-internal'>Required (defined)</span>
    :type account_id: int
    :param account_meter_ids: Destination AccountMeter Ids <span
     class='property-internal'>Required (defined)</span>
    :type account_meter_ids: list[int]
    :param update_account_gls: Use Account General Ledger from destination
     account? <span class='property-internal'>Required (defined)</span>
    :type update_account_gls: bool
    :param update_meter_gls: Use Meter General Ledger from destination meter?
     <span class='property-internal'>Required (defined)</span>
    :type update_meter_gls: bool
    :param update_record_scope_and_factor: If both the source and destination
     meter is linked to an emissions source and there are records generated
     from the bills being moved,
     update the scope category and GHG factor on those records to the
     destination meter defaults?
     Defaults to true for GHG Lite users, otherwise false. <span
     class='property-internal'>Required (defined)</span>
    :type update_record_scope_and_factor: bool
    """

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_meter_ids': {'key': 'accountMeterIds', 'type': '[int]'},
        'update_account_gls': {'key': 'updateAccountGLs', 'type': 'bool'},
        'update_meter_gls': {'key': 'updateMeterGLs', 'type': 'bool'},
        'update_record_scope_and_factor': {'key': 'updateRecordScopeAndFactor', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillActionMove, self).__init__(**kwargs)
        self.ids = kwargs.get('ids', None)
        self.account_id = kwargs.get('account_id', None)
        self.account_meter_ids = kwargs.get('account_meter_ids', None)
        self.update_account_gls = kwargs.get('update_account_gls', None)
        self.update_meter_gls = kwargs.get('update_meter_gls', None)
        self.update_record_scope_and_factor = kwargs.get('update_record_scope_and_factor', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceResponse(Model):
    """EmissionSourceResponse.

    :param emission_source_id: The emission source identifier
    :type emission_source_id: int
    :param emission_source_code: The emission source code
    :type emission_source_code: str
    :param emission_source_info: The emission source info
    :type emission_source_info: str
    :param collection:
    :type collection: ~energycap.sdk.models.CollectionChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param default_scope_category:
    :type default_scope_category: ~energycap.sdk.models.GHGScopeCategoryChild
    :param default_emission_factor:
    :type default_emission_factor: ~energycap.sdk.models.GHGFactorChild
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the emission source was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification of
     the emission source
    :type modified_date: datetime
    :param note: The emission source description
    :type note: str
    :param active: Indicates whether the emission source is active
    :type active: bool
    :param meter:
    :type meter: ~energycap.sdk.models.MeterLink
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
        'emission_source_code': {'key': 'emissionSourceCode', 'type': 'str'},
        'emission_source_info': {'key': 'emissionSourceInfo', 'type': 'str'},
        'collection': {'key': 'collection', 'type': 'CollectionChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'default_scope_category': {'key': 'defaultScopeCategory', 'type': 'GHGScopeCategoryChild'},
        'default_emission_factor': {'key': 'defaultEmissionFactor', 'type': 'GHGFactorChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'meter': {'key': 'meter', 'type': 'MeterLink'},
    }

    def __init__(self, *, emission_source_id: int=None, emission_source_code: str=None, emission_source_info: str=None, collection=None, commodity=None, default_scope_category=None, default_emission_factor=None, address=None, created_by=None, created_date=None, modified_by=None, modified_date=None, note: str=None, active: bool=None, meter=None, **kwargs) -> None:
        super(EmissionSourceResponse, self).__init__(**kwargs)
        self.emission_source_id = emission_source_id
        self.emission_source_code = emission_source_code
        self.emission_source_info = emission_source_info
        self.collection = collection
        self.commodity = commodity
        self.default_scope_category = default_scope_category
        self.default_emission_factor = default_emission_factor
        self.address = address
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.note = note
        self.active = active
        self.meter = meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettings(Model):
    """EnergyStarSettings.

    :param submit_by_commodity_only: Indicates to always configure ENERGY STAR
     on a per commodity basis
    :type submit_by_commodity_only: bool
    """

    _attribute_map = {
        'submit_by_commodity_only': {'key': 'submitByCommodityOnly', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSettings, self).__init__(**kwargs)
        self.submit_by_commodity_only = kwargs.get('submit_by_commodity_only', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityLinkChild(Model):
    """EnergyStarCommodityLinkChild.

    :param pm_meter_id: The Portfolio Manager meter identifier
    :type pm_meter_id: long
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param energy_star_compatible: Indicates if the commodity is compatible
     with ENERGY STAR
    :type energy_star_compatible: bool
    """

    _attribute_map = {
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'energy_star_compatible': {'key': 'energyStarCompatible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarCommodityLinkChild, self).__init__(**kwargs)
        self.pm_meter_id = kwargs.get('pm_meter_id', None)
        self.commodity = kwargs.get('commodity', None)
        self.energy_star_compatible = kwargs.get('energy_star_compatible', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionRecordRequest(Model):
    """EmissionRecordRequest.

    All required parameters must be populated in order to send to Azure.

    :param emission_source_id: Required. The Emission Source this record will
     be assigned to <span class='property-internal'>Required</span>
    :type emission_source_id: int
    :param begin_date: Required. The begin date for this record <span
     class='property-internal'>Required</span>
    :type begin_date: datetime
    :param end_date: Required. The end date for this record <span
     class='property-internal'>Required</span>
    :type end_date: datetime
    :param vendor_id: The supplier for this record <span
     class='property-internal'>Required (defined)</span>
    :type vendor_id: int
    :param record_type_id: Required. The type of this record. Valid values
     are:
     1 - Use
     2 - Cost
     3 - Direct/Offset <span class='property-internal'>Required</span> <span
     class='property-internal'>One of 1, 2, 3 </span>
    :type record_type_id: int
    :param scope_category_id: Required. The scope category for this record
     <span class='property-internal'>Required</span>
    :type scope_category_id: int
    :param factor_id: Required. The factor for this record <span
     class='property-internal'>Required</span>
    :type factor_id: int
    :param quantity: The use that is being tracked by this record.
     This value is required if RecordTypeId is set to 1 (Use) or 3
     (Direct/Offset),
     but must be left null if RecordTypeId is set to 2 (Cost). <span
     class='property-internal'>Required when RecordTypeId is set to 1, or
     3</span>
    :type quantity: float
    :param quantity_unit_id: The unit for the use being tracked by this
     record.
     This value is required if RecordTypeId is set to 1 (Use) or 3
     (Direct/Offset),
     but must be left null if RecordTypeId is set to 2 (Cost). <span
     class='property-internal'>Required when RecordTypeId is set to 1, or
     3</span>
    :type quantity_unit_id: int
    :param cost: The cost for this record
     Required if RecordTypeId is set to 2 (Cost), otherwise it is optional.
     <span class='property-internal'>Required when RecordTypeId is set to
     2</span>
    :type cost: float
    :param cost_unit_id: The unit for this record's cost.
     Required if RecordTypeId is set to 2 (Cost), otherwise it is optional.
     <span class='property-internal'>Required when RecordTypeId is set to
     2</span>
    :type cost_unit_id: int
    :param note: The note for this record <span class='property-internal'>Must
     be between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    :param attachment: The attachment for this record <span
     class='property-internal'>Must be between 0 and 260 characters</span>
     <span class='property-internal'>Required (defined)</span>
    :type attachment: str
    """

    _validation = {
        'emission_source_id': {'required': True},
        'begin_date': {'required': True},
        'end_date': {'required': True},
        'record_type_id': {'required': True},
        'scope_category_id': {'required': True},
        'factor_id': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
        'attachment': {'max_length': 260, 'min_length': 0},
    }

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'record_type_id': {'key': 'recordTypeId', 'type': 'int'},
        'scope_category_id': {'key': 'scopeCategoryId', 'type': 'int'},
        'factor_id': {'key': 'factorId', 'type': 'int'},
        'quantity': {'key': 'quantity', 'type': 'float'},
        'quantity_unit_id': {'key': 'quantityUnitId', 'type': 'int'},
        'cost': {'key': 'cost', 'type': 'float'},
        'cost_unit_id': {'key': 'costUnitId', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
        'attachment': {'key': 'attachment', 'type': 'str'},
    }

    def __init__(self, *, emission_source_id: int, begin_date, end_date, record_type_id: int, scope_category_id: int, factor_id: int, vendor_id: int=None, quantity: float=None, quantity_unit_id: int=None, cost: float=None, cost_unit_id: int=None, note: str=None, attachment: str=None, **kwargs) -> None:
        super(EmissionRecordRequest, self).__init__(**kwargs)
        self.emission_source_id = emission_source_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.vendor_id = vendor_id
        self.record_type_id = record_type_id
        self.scope_category_id = scope_category_id
        self.factor_id = factor_id
        self.quantity = quantity
        self.quantity_unit_id = quantity_unit_id
        self.cost = cost
        self.cost_unit_id = cost_unit_id
        self.note = note
        self.attachment = attachment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceLink(Model):
    """EmissionSourceLink.

    :param emission_source_id: The identifier for an Emission source.
    :type emission_source_id: int
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EmissionSourceLink, self).__init__(**kwargs)
        self.emission_source_id = kwargs.get('emission_source_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceMetricsResponse(Model):
    """EnergyStarPlaceMetricsResponse.

    :param calendar_period: The year and month for the ENERGY STAR score
    :type calendar_period: int
    :param score: The ENERGY STAR score
    :type score: int
    :param date_received: The date the score was received
    :type date_received: datetime
    :param site_energy_use: The weather-normalized property energy use (kBtu)
    :type site_energy_use: float
    :param site_energy_use_intensity: The weather-normalized property energy
     use intensity (kBtu/ft²)
    :type site_energy_use_intensity: float
    :param national_median_score: The national median ENERGY STAR score for
     the same type of property
    :type national_median_score: int
    :param national_median_site_energy_use_intensity: The national median
     weather-normalized property energy use intensity (kBtu/ft²)
    :type national_median_site_energy_use_intensity: float
    :param pct_diff_national_median_site_energy_use_intensity: The percent
     difference in the property energy use intensity vs. the national median
    :type pct_diff_national_median_site_energy_use_intensity: float
    """

    _attribute_map = {
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'score': {'key': 'score', 'type': 'int'},
        'date_received': {'key': 'dateReceived', 'type': 'iso-8601'},
        'site_energy_use': {'key': 'siteEnergyUse', 'type': 'float'},
        'site_energy_use_intensity': {'key': 'siteEnergyUseIntensity', 'type': 'float'},
        'national_median_score': {'key': 'nationalMedianScore', 'type': 'int'},
        'national_median_site_energy_use_intensity': {'key': 'nationalMedianSiteEnergyUseIntensity', 'type': 'float'},
        'pct_diff_national_median_site_energy_use_intensity': {'key': 'pctDiffNationalMedianSiteEnergyUseIntensity', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceMetricsResponse, self).__init__(**kwargs)
        self.calendar_period = kwargs.get('calendar_period', None)
        self.score = kwargs.get('score', None)
        self.date_received = kwargs.get('date_received', None)
        self.site_energy_use = kwargs.get('site_energy_use', None)
        self.site_energy_use_intensity = kwargs.get('site_energy_use_intensity', None)
        self.national_median_score = kwargs.get('national_median_score', None)
        self.national_median_site_energy_use_intensity = kwargs.get('national_median_site_energy_use_intensity', None)
        self.pct_diff_national_median_site_energy_use_intensity = kwargs.get('pct_diff_national_median_site_energy_use_intensity', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGTargetEmissions(Model):
    """GHGTargetEmissions.

    :param base_target_year:
    :type base_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    :param adjusted_target_year:
    :type adjusted_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    :param adjusted_ytd_target_year:
    :type adjusted_ytd_target_year: ~energycap.sdk.models.GHGYearlyEmissions
    """

    _attribute_map = {
        'base_target_year': {'key': 'baseTargetYear', 'type': 'GHGYearlyEmissions'},
        'adjusted_target_year': {'key': 'adjustedTargetYear', 'type': 'GHGYearlyEmissions'},
        'adjusted_ytd_target_year': {'key': 'adjustedYTDTargetYear', 'type': 'GHGYearlyEmissions'},
    }

    def __init__(self, *, base_target_year=None, adjusted_target_year=None, adjusted_ytd_target_year=None, **kwargs) -> None:
        super(GHGTargetEmissions, self).__init__(**kwargs)
        self.base_target_year = base_target_year
        self.adjusted_target_year = adjusted_target_year
        self.adjusted_ytd_target_year = adjusted_ytd_target_year



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesValue(Model):
    """TimeSeriesValue.

    :param id:
    :type id: int
    :param formatted_value:
    :type formatted_value: str
    :param date_property:
    :type date_property: datetime
    :param value:
    :type value: float
    :param unit:
    :type unit: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'formatted_value': {'key': 'formattedValue', 'type': 'str'},
        'date_property': {'key': 'date', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimeSeriesValue, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.formatted_value = kwargs.get('formatted_value', None)
        self.date_property = kwargs.get('date_property', None)
        self.value = kwargs.get('value', None)
        self.unit = kwargs.get('unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CollectionEmissionSourceChild(Model):
    """CollectionEmissionSourceChild.

    :param emission_source_id: The emission source identifier
    :type emission_source_id: int
    :param emission_source_code: The emission source code
    :type emission_source_code: str
    :param emission_source_info: The emission source info
    :type emission_source_info: str
    :param active: Whether the emission source is active or not
    :type active: bool
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
        'emission_source_code': {'key': 'emissionSourceCode', 'type': 'str'},
        'emission_source_info': {'key': 'emissionSourceInfo', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, **kwargs):
        super(CollectionEmissionSourceChild, self).__init__(**kwargs)
        self.emission_source_id = kwargs.get('emission_source_id', None)
        self.emission_source_code = kwargs.get('emission_source_code', None)
        self.emission_source_info = kwargs.get('emission_source_info', None)
        self.active = kwargs.get('active', None)
        self.commodity = kwargs.get('commodity', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CollectionRequest(Model):
    """CollectionRequest.

    All required parameters must be populated in order to send to Azure.

    :param collection_code: Required. The collection code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type collection_code: str
    :param collection_info: Required. The collection info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type collection_info: str
    :param parent_collection_id: Required. The identifier for the parent of
     the collection. The parent is the collection directly above the current
     collection on the collections and emission sources tree <span
     class='property-internal'>Required</span>
    :type parent_collection_id: int
    :param collection_icon:
    :type collection_icon: ~energycap.sdk.models.Icon
    :param note: The collection note <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    """

    _validation = {
        'collection_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'collection_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'parent_collection_id': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'collection_code': {'key': 'collectionCode', 'type': 'str'},
        'collection_info': {'key': 'collectionInfo', 'type': 'str'},
        'parent_collection_id': {'key': 'parentCollectionId', 'type': 'int'},
        'collection_icon': {'key': 'collectionIcon', 'type': 'Icon'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(CollectionRequest, self).__init__(**kwargs)
        self.collection_code = kwargs.get('collection_code', None)
        self.collection_info = kwargs.get('collection_info', None)
        self.parent_collection_id = kwargs.get('parent_collection_id', None)
        self.collection_icon = kwargs.get('collection_icon', None)
        self.note = kwargs.get('note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorVersionHistoryResponse(Model):
    """GHGFactorVersionHistoryResponse.

    :param factor_id: Identifier for the factor
    :type factor_id: str
    :param factor_info: Name of the factor
    :type factor_info: str
    :param factor_description: Description of the factor
    :type factor_description: str
    :param factor_unit:
    :type factor_unit: ~energycap.sdk.models.UnitChild
    :param factor_co2_eunit:
    :type factor_co2_eunit: ~energycap.sdk.models.UnitChild
    :param commodity_unit:
    :type commodity_unit: ~energycap.sdk.models.UnitChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param factor_category:
    :type factor_category: ~energycap.sdk.models.GHGFactorCategory
    :param versions: List of versions
    :type versions: list[~energycap.sdk.models.GHGVersion]
    """

    _attribute_map = {
        'factor_id': {'key': 'factorId', 'type': 'str'},
        'factor_info': {'key': 'factorInfo', 'type': 'str'},
        'factor_description': {'key': 'factorDescription', 'type': 'str'},
        'factor_unit': {'key': 'factorUnit', 'type': 'UnitChild'},
        'factor_co2_eunit': {'key': 'factorCO2EUnit', 'type': 'UnitChild'},
        'commodity_unit': {'key': 'commodityUnit', 'type': 'UnitChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'factor_category': {'key': 'factorCategory', 'type': 'GHGFactorCategory'},
        'versions': {'key': 'versions', 'type': '[GHGVersion]'},
    }

    def __init__(self, *, factor_id: str=None, factor_info: str=None, factor_description: str=None, factor_unit=None, factor_co2_eunit=None, commodity_unit=None, commodity=None, factor_category=None, versions=None, **kwargs) -> None:
        super(GHGFactorVersionHistoryResponse, self).__init__(**kwargs)
        self.factor_id = factor_id
        self.factor_info = factor_info
        self.factor_description = factor_description
        self.factor_unit = factor_unit
        self.factor_co2_eunit = factor_co2_eunit
        self.commodity_unit = commodity_unit
        self.commodity = commodity
        self.factor_category = factor_category
        self.versions = versions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorRegion(Model):
    """GHGFactorRegion.

    :param factor_region_id: The Factor Region identifier
    :type factor_region_id: int
    :param factor_region_info: The Factor Region info
    :type factor_region_info: str
    """

    _attribute_map = {
        'factor_region_id': {'key': 'factorRegionId', 'type': 'int'},
        'factor_region_info': {'key': 'factorRegionInfo', 'type': 'str'},
    }

    def __init__(self, *, factor_region_id: int=None, factor_region_info: str=None, **kwargs) -> None:
        super(GHGFactorRegion, self).__init__(**kwargs)
        self.factor_region_id = factor_region_id
        self.factor_region_info = factor_region_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityRequest(Model):
    """CommodityRequest.

    All required parameters must be populated in order to send to Azure.

    :param commodity_info: Required. The commodity info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type commodity_info: str
    :param abbreviation: Required. Three letter abbreviation code to represent
     the commodity <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 3 characters</span>
    :type abbreviation: str
    :param description: The commodity description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type description: str
    :param icon:
    :type icon: ~energycap.sdk.models.Icon
    :param commodity_category_id: The commodity category identifier <br />
     If the category is provided, the default rollup unit for that category
     will be used
    :type commodity_category_id: int
    :param commodity_rollup_unit_id: The common use unit identifier for
     reporting purposes <br />
     Ignored if a commodity category is provided and it has a rollup unit
     specified
    :type commodity_rollup_unit_id: int
    :param include_in_energy_reporting: Indicates if the commodity should be
     included in Energy reporting
    :type include_in_energy_reporting: bool
    :param energy_reporting_unit_conversion_multiplier: The multiplier to
     convert from the commodity rollup unit to the energy use reporting unit
     <br />
     Not required if commodity rollup unit is in the energy unit category
    :type energy_reporting_unit_conversion_multiplier: float
    """

    _validation = {
        'commodity_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'abbreviation': {'required': True, 'max_length': 3, 'min_length': 1},
        'description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'abbreviation': {'key': 'abbreviation', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'icon': {'key': 'icon', 'type': 'Icon'},
        'commodity_category_id': {'key': 'commodityCategoryId', 'type': 'int'},
        'commodity_rollup_unit_id': {'key': 'commodityRollupUnitId', 'type': 'int'},
        'include_in_energy_reporting': {'key': 'includeInEnergyReporting', 'type': 'bool'},
        'energy_reporting_unit_conversion_multiplier': {'key': 'energyReportingUnitConversionMultiplier', 'type': 'float'},
    }

    def __init__(self, *, commodity_info: str, abbreviation: str, description: str=None, icon=None, commodity_category_id: int=None, commodity_rollup_unit_id: int=None, include_in_energy_reporting: bool=None, energy_reporting_unit_conversion_multiplier: float=None, **kwargs) -> None:
        super(CommodityRequest, self).__init__(**kwargs)
        self.commodity_info = commodity_info
        self.abbreviation = abbreviation
        self.description = description
        self.icon = icon
        self.commodity_category_id = commodity_category_id
        self.commodity_rollup_unit_id = commodity_rollup_unit_id
        self.include_in_energy_reporting = include_in_energy_reporting
        self.energy_reporting_unit_conversion_multiplier = energy_reporting_unit_conversion_multiplier



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetCreate(Model):
    """WidgetCreate.

    All required parameters must be populated in order to send to Azure.

    :param widget_id: Required. Widget identifier <span
     class='property-internal'>Required</span>
    :type widget_id: int
    :param row: Required. Dashboard row <span
     class='property-internal'>Required</span>
    :type row: int
    :param col: Required. Dashboard column <span
     class='property-internal'>Required</span>
    :type col: int
    :param height: Required. Widget height <span
     class='property-internal'>Required</span>
    :type height: int
    :param width: Required. Widget width <span
     class='property-internal'>Required</span>
    :type width: int
    :param title: Required. Personal Widget title <span
     class='property-internal'>Must be between 0 and 600 characters</span>
     <span class='property-internal'>Required</span>
    :type title: str
    :param user_widget_description: Personal Widget description <span
     class='property-internal'>Must be between 0 and 600 characters</span>
    :type user_widget_description: str
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterEdit]
    """

    _validation = {
        'widget_id': {'required': True},
        'row': {'required': True},
        'col': {'required': True},
        'height': {'required': True},
        'width': {'required': True},
        'title': {'required': True, 'max_length': 600, 'min_length': 0},
        'user_widget_description': {'max_length': 600, 'min_length': 0},
    }

    _attribute_map = {
        'widget_id': {'key': 'widgetId', 'type': 'int'},
        'row': {'key': 'row', 'type': 'int'},
        'col': {'key': 'col', 'type': 'int'},
        'height': {'key': 'height', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'title': {'key': 'title', 'type': 'str'},
        'user_widget_description': {'key': 'userWidgetDescription', 'type': 'str'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
    }

    def __init__(self, *, widget_id: int, row: int, col: int, height: int, width: int, title: str, user_widget_description: str=None, filters=None, **kwargs) -> None:
        super(WidgetCreate, self).__init__(**kwargs)
        self.widget_id = widget_id
        self.row = row
        self.col = col
        self.height = height
        self.width = width
        self.title = title
        self.user_widget_description = user_widget_description
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsDataPoint(Model):
    """WatticsDataPoint.

    :param wattics_data_point_id: The identifier for a Wattics meter
    :type wattics_data_point_id: int
    """

    _attribute_map = {
        'wattics_data_point_id': {'key': 'watticsDataPointId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(WatticsDataPoint, self).__init__(**kwargs)
        self.wattics_data_point_id = kwargs.get('wattics_data_point_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FailedReadings(Model):
    """FailedReadings.

    :param time:
    :type time: datetime
    :param value:
    :type value: float
    :param estimated:
    :type estimated: bool
    :param note:
    :type note: str
    :param error:
    :type error: str
    """

    _attribute_map = {
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, *, time=None, value: float=None, estimated: bool=None, note: str=None, error: str=None, **kwargs) -> None:
        super(FailedReadings, self).__init__(**kwargs)
        self.time = time
        self.value = value
        self.estimated = estimated
        self.note = note
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EmissionSourceLinkRequest(Model):
    """EmissionSourceLinkRequest.

    :param emission_source_id: The identifier for an Emission source.
     Set to null to remove the link. <span class='property-internal'>Topmost
     (EmissionSource)</span> <span class='property-internal'>Required
     (defined)</span>
    :type emission_source_id: int
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
    }

    def __init__(self, *, emission_source_id: int=None, **kwargs) -> None:
        super(EmissionSourceLinkRequest, self).__init__(**kwargs)
        self.emission_source_id = emission_source_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UtilityPlatform(Model):
    """UtilityPlatform.

    :param data_release_file_url: Date Release file Url used to record Data
     access release
    :type data_release_file_url: str
    :param utility_platform_provider_key: Identifier for the Utility Platform
     Provider Organization
    :type utility_platform_provider_key: str
    :param utility_platform_provider_info: Name of the Utility Platform
     Provider Organization
    :type utility_platform_provider_info: str
    :param can_decline_data_release: Flag to indicate if Data Release requests
     from this Utility Provider can be declined
    :type can_decline_data_release: bool
    """

    _attribute_map = {
        'data_release_file_url': {'key': 'dataReleaseFileUrl', 'type': 'str'},
        'utility_platform_provider_key': {'key': 'utilityPlatformProviderKey', 'type': 'str'},
        'utility_platform_provider_info': {'key': 'utilityPlatformProviderInfo', 'type': 'str'},
        'can_decline_data_release': {'key': 'canDeclineDataRelease', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(UtilityPlatform, self).__init__(**kwargs)
        self.data_release_file_url = kwargs.get('data_release_file_url', None)
        self.utility_platform_provider_key = kwargs.get('utility_platform_provider_key', None)
        self.utility_platform_provider_info = kwargs.get('utility_platform_provider_info', None)
        self.can_decline_data_release = kwargs.get('can_decline_data_release', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportingSettingRequest(Model):
    """ReportingSettingRequest.

    :param energy_unit_id: The energy unit identifier <span
     class='property-internal'>Required (defined)</span>
    :type energy_unit_id: int
    :param cost_unit_id: The cost unit identifier <span
     class='property-internal'>Required (defined)</span>
    :type cost_unit_id: int
    :param floor_area_unit_id: The floor area unit identifier <span
     class='property-internal'>Required (defined)</span>
    :type floor_area_unit_id: int
    :param months_to_exclude_from_charts: Months to exclude from charts,
     including the current month.
     Ex. If the current month is October,
     A value of 0 will not exclude any months,
     A value of 1 will exclude the month of October,
     A value of 2 will exclude October and September,
     A value of 3 will exclude October, September, and August,
     A value of 13 will exclude October and the last full year of data. <span
     class='property-internal'>Must be between 0 and 13</span> <span
     class='property-internal'>Required (defined)</span>
    :type months_to_exclude_from_charts: int
    """

    _validation = {
        'months_to_exclude_from_charts': {'maximum': 13, 'minimum': 0},
    }

    _attribute_map = {
        'energy_unit_id': {'key': 'energyUnitId', 'type': 'int'},
        'cost_unit_id': {'key': 'costUnitId', 'type': 'int'},
        'floor_area_unit_id': {'key': 'floorAreaUnitId', 'type': 'int'},
        'months_to_exclude_from_charts': {'key': 'monthsToExcludeFromCharts', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ReportingSettingRequest, self).__init__(**kwargs)
        self.energy_unit_id = kwargs.get('energy_unit_id', None)
        self.cost_unit_id = kwargs.get('cost_unit_id', None)
        self.floor_area_unit_id = kwargs.get('floor_area_unit_id', None)
        self.months_to_exclude_from_charts = kwargs.get('months_to_exclude_from_charts', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchEmissionSourceChildSearchEmissionSource(Model):
    """SearchEmissionSourceChildSearchEmissionSource.

    :param emission_source_id: The emissions source identifier
    :type emission_source_id: int
    :param emission_source_code: The emissions source code
    :type emission_source_code: str
    :param emission_source_info: The emissions source info
    :type emission_source_info: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param parent_path: The collection of CarbonHub collections representing
     the path to its parent
    :type parent_path: list[~energycap.sdk.models.CollectionChild]
    :param active: Indicates whether or not the emissions source is active
    :type active: bool
    :param postal_code: The address postal code
    :type postal_code: str
    :param city: The address city
    :type city: str
    :param state: The address state
    :type state: str
    :param country: The address country
    :type country: str
    :param line1: The address first line
    :type line1: str
    :param line2: The address second line
    :type line2: str
    :param line3: The address third line
    :type line3: str
    """

    _attribute_map = {
        'emission_source_id': {'key': 'emissionSourceId', 'type': 'int'},
        'emission_source_code': {'key': 'emissionSourceCode', 'type': 'str'},
        'emission_source_info': {'key': 'emissionSourceInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'parent_path': {'key': 'parentPath', 'type': '[CollectionChild]'},
        'active': {'key': 'active', 'type': 'bool'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SearchEmissionSourceChildSearchEmissionSource, self).__init__(**kwargs)
        self.emission_source_id = kwargs.get('emission_source_id', None)
        self.emission_source_code = kwargs.get('emission_source_code', None)
        self.emission_source_info = kwargs.get('emission_source_info', None)
        self.commodity = kwargs.get('commodity', None)
        self.parent_path = kwargs.get('parent_path', None)
        self.active = kwargs.get('active', None)
        self.postal_code = kwargs.get('postal_code', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
        self.line1 = kwargs.get('line1', None)
        self.line2 = kwargs.get('line2', None)
        self.line3 = kwargs.get('line3', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityCategory(Model):
    """CommodityCategory.

    :param commodity_category_id: The commodity category id
    :type commodity_category_id: int
    :param commodity_category_info: The commodity category info
    :type commodity_category_info: str
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'commodity_category_id': {'key': 'commodityCategoryId', 'type': 'int'},
        'commodity_category_info': {'key': 'commodityCategoryInfo', 'type': 'str'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, *, commodity_category_id: int=None, commodity_category_info: str=None, common_use_unit=None, common_demand_unit=None, **kwargs) -> None:
        super(CommodityCategory, self).__init__(**kwargs)
        self.commodity_category_id = commodity_category_id
        self.commodity_category_info = commodity_category_info
        self.common_use_unit = common_use_unit
        self.common_demand_unit = common_demand_unit
